summaryrefslogtreecommitdiffstats
path: root/sys
diff options
context:
space:
mode:
authormav <mav@FreeBSD.org>2009-02-12 09:37:45 +0000
committermav <mav@FreeBSD.org>2009-02-12 09:37:45 +0000
commit9770977c8f893694dc5d4e0806ce07436d3ab3c1 (patch)
tree97c9fb6fb1c020a470dd73b2bc2ddb0b22eb4aca /sys
parent2a2a8639b113f07771089ec4733cafa8639b5046 (diff)
downloadFreeBSD-src-9770977c8f893694dc5d4e0806ce07436d3ab3c1.zip
FreeBSD-src-9770977c8f893694dc5d4e0806ce07436d3ab3c1.tar.gz
s/succeded/succeeded/ in comments.
Diffstat (limited to 'sys')
-rw-r--r--sys/dev/sound/pci/hda/hdac.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/dev/sound/pci/hda/hdac.c b/sys/dev/sound/pci/hda/hdac.c
index afdd638..7184159 100644
--- a/sys/dev/sound/pci/hda/hdac.c
+++ b/sys/dev/sound/pci/hda/hdac.c
@@ -4981,7 +4981,7 @@ hdac_audio_trace_as_out(struct hdac_devinfo *devinfo, int as, int seq)
/* Find next pin */
for (i = seq; i < 16 && ases[as].pins[i] == 0; i++)
;
/* Check if there is no any left. If so - we succeded. */
if (i == 16)
return (1);
@@ -5027,7 +5027,7 @@ hdac_audio_trace_as_out(struct hdac_devinfo *devinfo, int as, int seq)
hdac_audio_trace_dac(devinfo, as, i,
ases[as].pins[i], hpredir, min, res, 0);
ases[as].dacs[i] = res;
/* We succeded, so call next. */
if (hdac_audio_trace_as_out(devinfo, as, i + 1))
return (1);
/* If next failed, we should retry with next min */
@@ -6002,7 +6002,7 @@ retry:
if (res) {
HDA_BOOTVERBOSE(
device_printf(devinfo->codec->sc->dev,
- "Association %d (%d) trace succeded\n",
+ "Association %d (%d) trace succeeded\n",
j, as[j].index);
);
} else {
@@ -4981,7 +4981,7 @@ hdac_audio_trace_as_out(struct hdac_devinfo *devinfo, int as, int seq)
for (i = seq; i < 16 && ases[as].pins[i] == 0; i++)
;
- /* Check if there is no any left. If so - we succeded. */
+ /* Check if there is no any left. If so - we succeeded. */
if (i == 16)
return (1);
@@ -5027,7 +5027,7 @@ hdac_audio_trace_as_out(struct hdac_devinfo *devinfo, int as, int seq)
ases[as].pins[i], hpredir, min, res, 0);
ases[as].dacs[i] = res;
- /* We succeded, so call next. */
+ /* We succeeded, so call next. */
if (hdac_audio_trace_as_out(devinfo, as, i + 1))
return (1);
OpenPOWER on IntegriCloud